@@ -79,14 +79,14 @@ connection.onopen = function (session) {
   var k=0;
   setInterval(function () {
     
-    session.call('com.test.add', [{x:2,y:3}]).then(
-            function (res) {
-                //for(var i=0;i<res.length;i++){
-                //  console.log(res[i].app_name);
-                //}
-                console.log("Result:", res);
-            }
-        );
+    // session.call('com.test.add', [{x:2,y:3}]).then(
+    //         function (res) {
+    //             //for(var i=0;i<res.length;i++){
+    //             //  console.log(res[i].app_name);
+    //             //}
+    //             console.log("Result:", res);
+    //         }
+    //     );
     
      session.publish('com.test.hello', ['Hello, world!::'+k]);
      k++;
